aboutsummaryrefslogtreecommitdiffhomepage
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/main/java/com/google/devtools/build/lib/analysis/RuleConfiguredTargetFactory.java15
1 files changed, 9 insertions, 6 deletions
diff --git a/src/main/java/com/google/devtools/build/lib/analysis/RuleConfiguredTargetFactory.java b/src/main/java/com/google/devtools/build/lib/analysis/RuleConfiguredTargetFactory.java
index ba6272de8d..dda6a01737 100644
--- a/src/main/java/com/google/devtools/build/lib/analysis/RuleConfiguredTargetFactory.java
+++ b/src/main/java/com/google/devtools/build/lib/analysis/RuleConfiguredTargetFactory.java
@@ -15,7 +15,10 @@ package com.google.devtools.build.lib.analysis;
import com.google.devtools.build.lib.actions.ActionAnalysisMetadata;
import com.google.devtools.build.lib.actions.MutableActionGraph.ActionConflictException;
+import com.google.devtools.build.lib.analysis.config.BuildConfiguration;
+import com.google.devtools.build.lib.cmdline.Label;
import com.google.devtools.build.lib.packages.RuleClass;
+import com.google.devtools.build.lib.skyframe.BuildConfigurationValue;
/**
* A shortcut class to the appropriate specialization of {@code RuleClass.ConfiguredTargetFactory}.
@@ -23,12 +26,12 @@ import com.google.devtools.build.lib.packages.RuleClass;
* <p>Here follows an overview of how loading and analysis works in Bazel:
*
* <p>Actions (i.e. commands that are run during the build) are created by configured targets (see
* {@link ConfiguredTarget}), which are a pair of a target (e.g. <code>//src:bazel</code>) and a
* {@link com.google.devtools.build.lib.analysis.config.BuildConfiguration}, which is a blob of data
* that contains extra information about how the target should be built (for example, for which
* platform or with which C++ preprocessor definitions). Accordingly, a target can give rise to
* multiple configured targets, for example, if it needs to be built both for the host and the
* target configuration.
*
* <p>The process of creating the appropriate {@link com.google.devtools.build.lib.actions.Action}s
* for a configured target is called "analysis". The analysis of a configured target is composed of
@@ -23,12 +26,12 @@ import com.google.devtools.build.lib.packages.RuleClass;
*
* <p>Actions (i.e. commands that are run during the build) are created by configured targets (see
- * {@link ConfiguredTarget}), which are a pair of a target (e.g. <code>//src:bazel</code>) and a
- * {@link com.google.devtools.build.lib.analysis.config.BuildConfiguration}, which is a blob of data
- * that contains extra information about how the target should be built (for example, for which
- * platform or with which C++ preprocessor definitions). Accordingly, a target can give rise to
- * multiple configured targets, for example, if it needs to be built both for the host and the
- * target configuration.
+ * {@link ConfiguredTarget}), which are a pair of a {@link Label} (e.g. <code>//src:bazel</code>)
+ * and a {@link BuildConfigurationValue#Key}, which is a key for a {@link BuildConfiguration}, which
+ * is a blob of data that contains extra information about how the target should be built (for
+ * example, for which platform or with which C++ preprocessor definitions). Accordingly, a target
+ * can give rise to multiple configured targets, for example, if it needs to be built both for the
+ * host and the target configuration.
*
* <p>The process of creating the appropriate {@link com.google.devtools.build.lib.actions.Action}s